% ABMart document class -- version: August 2003
% LaTeX document class for "AMAS Conference Proceedings" (article style) 
% 2003(c)Tomasz G. Zielinski (Warsaw, Poland)
%
% Modified by Maciej Stanczyk to fit the needs of "Abiomed Lecture Notes"

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ABMart}[2003/08/15 -- article style for abiomed Lecture Notes, multiple lectures]
\DeclareOption{oneside}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[twoside]{article}
\frenchspacing

%===== REQUIRED PACKAGES ==========================================
\RequirePackage{amsmath}[2000/06/06]
 %\setlength\multlinetaggap{6\p@}
  \setlength\multlinegap{\z@}
\RequirePackage{amsthm}[2000/06/02]
%==================================================================

%===== DIMENSIONS =================================================
\DeclareOption{10pt}{\setlength\textheight{46\baselineskip}}
\DeclareOption{11pt}{\setlength\textheight{40\baselineskip}}
\DeclareOption{12pt}{\setlength\textheight{36\baselineskip}}
\ProcessOptions\relax

\setlength\voffset{-1in}
\setlength\hoffset{-1in}

\setlength\paperwidth{166mm}
\setlength\paperheight{236mm}
\setlength\textwidth{127mm}
\setlength\oddsidemargin{22mm}
\setlength\evensidemargin{\oddsidemargin}
\setlength\topmargin{18mm}
\setlength\headheight{12\p@}
\setlength\headsep{3mm}
\setlength\topskip{1.2\baselineskip}
\advance\textheight\topskip
\setlength\footskip{40mm}  %\setlength\footskip{10mm}

\setlength\parindent{1.5em}
\setlength\parskip{0\p@}
\setlength\itemsep{0\p@}
\setlength\partopsep{3\p@}
\setlength\topsep{0\p@}
%==================================================================

%===== PAGE STYLES ================================================
\newcommand\@headrule[1]{\small#1\hskip-\hsize\rule[-1mm]{\hsize}{.4\p@}}

\def\ps@headings{\let\@mkboth\markboth
  \def\@oddhead{\@headrule{\hspace{2ex}\hfil{\scshape\leftmark}\hfil\hspace{2ex}\llap{\large\thepage}}}%
  \def\@evenhead{\@headrule{\rlap{\large\thepage}\hspace{2ex}\hfil\scshape\rightmark\hfil\hspace{2ex}}}%
  \let\@oddfoot\@empty
  \let\@evenfoot\@oddfoot}
  
\pagestyle{headings}

\newcommand\paperhead[2]{%
  \gdef\@paperHeadFirstLine{#1}%
  \gdef\@paperHeadSecondLine{#2}}
\gdef\@paperHeadFirstLine{Article style for abiomed Lecture Notes}
\gdef\@paperHeadSecondLine{ABMart.cls -- (pp.\paperpages) -- Warsaw, February 2004.}

\newcommand\paperpages{\thepage--\pageref{@ndofpap@r\thepaper}}

\def\ps@titlepage{\leftskip\z@\let\@mkboth\@gobbletwo
  \def\@oddhead{\hfil\small{\scshape \@paperHeadFirstLine}\hfil}
  \let\@evenhead\@oddhead
  \let\@oddfoot\@noNumberPage%\let\@oddfoot\@empty
  \let\@evenfoot\@oddfoot
  \let\sectionmark\@gobble
  \let\subsectionmark\@gobble}

\def\ps@Empty{\let\@mkboth\@gobbletwo
     \let\@oddhead\@empty\let\@oddfoot\@noNumberPage
     \let\@evenhead\@empty\let\@evenfoot\@oddfoot}

%\newif\if@vacat

\def\@noNumberPage{\reset@font\hfil[\thepage]
     %\if@vacat\@vacatfalse ~(poprz. strona: VACAT!)\fi
     \hfil}

%\let\ps@Empty\ps@empty
%==================================================================

%===== PAPER ENVIRONMENT ==========================================
\newcounter{current}
\newcounter{paper}

\newenvironment{paper}{%
  \begingroup
  \standardnumbering
  \stepcounter{paper}
  \setcounter{current}{0}
  \setcounter{affiliation}{0}
  \setcounter{equation}{0}
  \setcounter{figure}{0}
  \setcounter{table}{0}
  \setcounter{section}{0}
  \setcounter{appendix}{0}
  \setcounter{footnote}{0}
  \setcounter{definition}{0}
  \setcounter{theorem}{0}
  \setcounter{case}{0}
  \setcounter{corollary}{0}
  \setcounter{example}{0}
  \setcounter{observation}{0}
  \setcounter{proposition}{0}
  \setcounter{remark}{0}
  \let\@part\relax
  \let\@author\relax
  \let\@tocauthor\relax
  \let\@headauthor\relax
  \let\@title\relax
  \let\@toctitle\relax
  \let\@headtitle\relax
  \let\@affiliationI\relax
  \let\@affiliationII\relax
  \let\@affiliationIII\relax
  \let\@affiliationIV\relax
  \let\@dedication\relax
  \let\@abstract\relax
  \let\@keywords\relax
  \clearpage
  \newoddpage
  \markboth{\@headtitle}{\@headauthor}
}{%
  \begin{center}
    \rule[.75mm]{10mm}{.5pt}\hspace{-.2mm}$\diamond$\hspace{-.2mm}\rule[0.75mm]{10mm}{.5pt}
  \end{center}\label{@ndofpap@r\thepaper}
  \endgroup
}

\newcommand{\newoddpage}{\ifodd\c@page\else\stepcounter{page}\fi}
%==================================================================

%===== FOR TITLE PAGE =============================================
\renewcommand\part{\@ifnextchar[{\@parttwo}{\@partone}}
\def\@parttwo[#1]#2{
  \newoddpage
  \thispagestyle{Empty}
  \vspace*{0.3\textheight}
  \hrule\vspace{1mm}\hrule
  \vspace{2mm}
  \begin{center}
    \normalfont\huge\bfseries #2
  \end{center}
  \vspace{2mm}
  \hrule\vspace{1mm}\hrule
  \addcontentsline{toc}{part}{#1}
  \newpage}
\def\@partone#1{\@parttwo[#1]{#1}}


\renewcommand\and{{\normalfont\rmfamily \protect\lowercase{and} }}

\renewcommand\author{\@ifnextchar[{\@authortwo}{\@authorone}}
\def\@authortwo[#1]#2{\long\gdef\@author{#2}%
   \if\@tocauthor\relax{\gdef\@tocauthor{#1}}\fi%
   \if\@headauthor\relax{\begingroup\def\and{and }\gdef\@headauthor{#1}\endgroup}\fi}
\def\@authorone#1{\@authortwo[#1]{#1}}
\gdef\@author{}

\newcommand\tocauthor[1]{\gdef\@tocauthor{#1}}
\gdef\@tocauthor{}

\newcommand\headauthor[1]{\gdef\@headauthor{#1}}
\gdef\@headauthor{}


\renewcommand\title{\@ifnextchar[{\@titletwo}{\@titleone}}
\def\@titletwo[#1]#2{\long\gdef\@title{#2}%
   \if\@toctitle\relax{\gdef\@toctitle{#2}}\fi%
   \if\@headtitle\relax{\gdef\@headtitle{#1}}\fi}
\def\@titleone#1{\@titletwo[#1]{#1}}
\gdef\@title{}

\newcommand\toctitle[1]{\gdef\@toctitle{#1}}
\gdef\@toctitle{}

\newcommand\headtitle[1]{\gdef\@headtitle{#1}}
\gdef\@headtitle{}


\newcounter{affiliation}
\newcommand\affiliation[1]{%
  \stepcounter{affiliation}%
  {\long\xdef\@temp{%
     \noexpand\long\noexpand\def\csname%
     @affiliation\Roman{affiliation}\endcsname}%
  }\@temp{#1}}


\newcommand\dedication[1]{\gdef\@dedication{#1}}
\gdef\@dedication{}

\renewcommand\abstract[1]{\gdef\@abstract{#1}}
\gdef\@abstract{}

\newcommand\keywords[1]{\gdef\@keywords{#1}}
\gdef\@keywords{}


\newcommand\getTOCauthor{\@tocauthor}
\newcommand\getTOCtitle{\@toctitle}
%==================================================================

%===== MAKETITLE ==================================================
\renewcommand\maketitle{\@maketitle}

\long\def\@iterate{\@iterationbody\let\next=\@iterate\else\let\next\relax\fi\next}

\def\@maketitle{%
  \begingroup
  \newpage
  \global\@topnum\z@
  \thispagestyle{titlepage}
  \vspace*{-\topskip}\vspace*{-\headsep}%
  {\small\scshape\centering \@paperHeadSecondLine\par}
  \vskip 20\p@ \@plus 4\p@ \@minus 1\p@
  \begin{center}
  \parbox{0.9\textwidth}
    {\sloppy{\centering
    \vskip 20\p@ \@plus 2\p@ \@minus 1\p@
    {\normalfont\Large\bfseries \@title\par}%
    \vskip 16\p@ \@plus 2\p@ \@minus 1\p@
    \if\@dedication\relax\else
       {\begin{flushright} \normalfont\small\itshape \@dedication \end{flushright}\par%
        \vskip 16\p@ \@plus 2\p@ \@minus 1\p@}\fi%
    {\normalfont\normalsize\rmfamily \@author\par}%
    \vskip 16\p@ \@plus 1\p@
    \setcounter{current}{0}
    \long\def\@iterationbody{
      \ifnum\thecurrent<\theaffiliation{\stepcounter{current}}
      {\itshape\normalsize \csname @affiliation\Roman{current}\endcsname\par}
      \vskip 10\p@ \@plus 1\p@
    }\@iterate}
    \vskip 10\p@ \@plus 1\p@ \@minus 1\p@
    {\normalfont\footnotesize\rmfamily \@abstract \par%
    \if\@keywords\relax\else{\vskip 8\p@ Key words: \itshape\@keywords \par}\fi}}
  \end{center}
  \vskip 14\p@ \@plus 2\p@ \@minus 1\p@
  \endgroup
  \addcontentsline{toc}{paper}{{\protect\sc \@tocauthor},\hspace{1ex}{\protect\em \@toctitle}}
  \@thanks
}
%==================================================================

%===== SECTIONING =================================================
\newcommand\standardnumbering{
  \renewcommand\thesection{\arabic{section}}
  \renewcommand\thesubsection{\thesection.\arabic{subsection}}
  \renewcommand\thesubsubsection{\thesubsection.\arabic{subsubsection}}
  \renewcommand{\theequation}{\thesection.\arabic{equation}}
  \@addtoreset{equation}{section}
  %\renewcommand{\theequation}{\arabic{equation}}
  }
\standardnumbering

\setcounter{secnumdepth}{3}

\renewcommand\section{\@startsection{section}{1}{\z@}%
                                   {3.5ex \@plus 1ex \@minus .2ex}%
                                   {2.3ex \@plus .2ex}%
                                   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                   {3.25ex \@plus 1ex \@minus .2ex}%
                                   {1.5ex \@plus .2ex}%
                                   {\normalfont\normalsize\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {-1.5ex}%
                                   {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\parindent}%
                                   {3ex \@plus .7ex \@minus .1ex}%
                                   {1.2ex \@plus .2ex}%
                                   {\itshape\normalsize}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                   {2ex \@plus .5ex \@minus .1ex}%
                                   {-.7em}%
                                   {\itshape\normalsize}}

\def\@seccntformat#1{\csname the#1\endcsname.\hspace{1.2ex}}


\newenvironment{notations}
   {\section*{Notations}%
    \normalfont\footnotesize\rmfamily}
   {\par}

\newcounter{appendix}
\def\theappendix{\Alph{appendix}}
%\renewcommand\appendix{\@ifnextchar[{\@appendixtwo}{\@appendixone}}
%\def\@appendixtwo[#1]#2{\par
%   \stepcounter{appendix}
%   \setcounter{subsection}{0}
%   \renewcommand\thesubsection{\theappendix.\arabic{subsection}}
%   \renewcommand\theequation{\theappendix.\arabic{equation}}
%   \def\thesection{#1}
%   \section{#2}
%   \addtocounter{section}{-1}}
%\def\@appendixone#1{\@appendixtwo[Appendix \theappendix]{#1}}

\newenvironment{acknowledgement}{\section*{Acknowledgement}}{\par}
\newenvironment{acknowledgements}{\section*{Acknowledgements}}{\par}
\let\acknowledgments\acknowledgements
\let\endacknowledgments\endacknowledgements
\let\acknowledgment\acknowledgement
\let\endacknowledgment\endacknowledgement
%==================================================================

%===== REFERENCES =================================================
\def\@biblabel#1{#1.}
\newenvironment{references}[1][xx]
   {\begin{thebibliography}{#1}%
    \footnotesize\parskip1\p@}
   {\end{thebibliography}}
   
\renewenvironment{thebibliography}[1]
     {\section*{\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
%==================================================================

%===== LISTS ======================================================
\def\itemize{%
  \ifnum \@itemdepth >\thr@@\@toodeep\else
    \advance\@itemdepth\@ne
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
    \expandafter
    \list
      \csname\@itemitem\endcsname
      {\itemsep2\p@ \parsep\z@ \topsep2\p@ \partopsep\z@
       \def\makelabel##1{\hss\llap{##1}}}%
  \fi}
\let\enditemize =\endlist

\def\enumerate{%
  \ifnum \@enumdepth >\thr@@\@toodeep\else
    \advance\@enumdepth\@ne
    \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
      \expandafter
      \list
        \csname label\@enumctr\endcsname
        {\usecounter\@enumctr
         \itemsep2\p@  \parsep\z@ \topsep2\p@ \partopsep\z@
         \def\makelabel##1{\hss\llap{##1}}}%
  \fi}

\renewenvironment{description}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \itemsep2\p@  \parsep\z@ \topsep2\p@ \partopsep\z@
                        \let\makelabel\descriptionlabel}}
               {\endlist}
%==================================================================

%===== NEWTHEOREMS ================================================
\newtheoremstyle{thmLemDef}% name
  {4pt}%      Space above
  {4pt}%      Space below
  {\itshape}% Body font
  {\parindent}%         Indent amount (empty = no indent, \parindent = para indent)
  {\bf}%      Thm head font
  {:}%        Punctuation after thm head
  {.5em}%     Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%         Thm head spec (can be left empty, meaning `normal')
  
\theoremstyle{thmLemDef}
 \newtheorem{theorem}{Theorem}
 \newtheorem{lemma}{Lemma}
 \newtheorem{definition}{Definition}
 \newtheorem*{theorem*}{Theorem}
 \newtheorem*{lemma*}{Lemma}
 \newtheorem*{definition*}{Definition}


\newtheoremstyle{other}% name
  {4pt}%      Space above
  {4pt}%      Space below
  {}%         Body font
  {\parindent}%         Indent amount (empty = no indent, \parindent = para indent)
  {\bf}%      Thm head font
  {.}%        Punctuation after thm head
  {.5em}%     Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%         Thm head spec (can be left empty, meaning `normal')
  
\theoremstyle{other}
 \newtheorem{case}{Case}
 \newtheorem{corollary}{Corollary}
 \newtheorem{example}{Example}
 \newtheorem{remark}{Remark}
 \newtheorem{observation}{Observation}
 \newtheorem{proposition}{Proposition}
 \newtheorem*{case*}{Case}
 \newtheorem*{corollary*}{Corollary}
 \newtheorem*{example*}{Example}
 \newtheorem*{remark*}{Remark}
 \newtheorem*{observation*}{Observation}
 \newtheorem*{proposition*}{Proposition}
 

\renewenvironment{proof}[1][]{\par
  \pushQED{\qed}%
  \normalfont
  \trivlist
  \item[\hskip\labelsep
        \indent\bf
    \proofname\@ifempty{#1}{}{~~(#1)}\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}
  
\newenvironment{proof*}[1][]{\par
  \normalfont
  \trivlist
  \item[\hskip\labelsep
        \indent\bf
    \proofname\@ifempty{#1}{}{~~(#1)}\@addpunct{.}]\ignorespaces
}{%
  \endtrivlist\@endpefalse
}

\renewcommand{\proofname}{Proof}
%==================================================================

%===== EQUATION ENVIRONMENTS ======================================
\def\@textsubscript#1{%
  {\m@th\ensuremath{_{\mbox{\fontsize\sf@size\z@#1}}}}}

\newenvironment{subnumbered}{%
  \refstepcounter{equation}%
  \protected@edef\theparentequation{\theequation}%
  \setcounter{parentequation}{\value{equation}}%
  \setcounter{equation}{0}%
  \def\theequation{\theparentequation\@textsubscript{\footnotesize\arabic{equation}}}%
  \ignorespaces
}{%
  \setcounter{equation}{\value{parentequation}}%
  \ignorespacesafterend}

\newenvironment{subnumbered*}{%
  \refstepcounter{equation}%
  \protected@edef\theparentequation{\theequation}%
  \setcounter{parentequation}{\value{equation}}%
  \setcounter{equation}{0}%
  \def\theequation{(\theparentequation)\@textsubscript{\footnotesize\arabic{equation}}}%
  \def\tagform@\theequation{%
     \maketag@@@{(\ignorespaces\theparentequation\unskip\@@italiccorr)%
                 \@textsubscript{\footnotesize\arabic{equation}}}}%
  \ignorespaces
}{%
  \setcounter{equation}{\value{parentequation}}%
  \ignorespacesafterend}


\newcommand\marknumberwith{\@ifnextchar*{\@marknumberstar}{\@marknumberwith}}
\def\@marknumberstar*#1{\tag*{(\theequation)#1}}
\def\@marknumberwith#1{\tag{\theequation#1}}


\newcommand\conteqn{
  \tabcolsep\z@
  \tag*{\protect\tabular{c}(\theequation)\\[-5pt]
        \tiny[cont.]\protect\endtabular}}
%==================================================================

%===== FOOTNOTE ===================================================
\def\@makefnmark{\hbox{\@textsuperscript{\normalfont\@thefnmark)}}}
%==================================================================

%===== ILLUSTRATIONS LAYOUT =======================================
\setcounter{topnumber}{2}
\renewcommand\topfraction{.8}
\setcounter{bottomnumber}{2}
\renewcommand\bottomfraction{.5}
\setcounter{totalnumber}{3}
\renewcommand\textfraction{.2}
\renewcommand\floatpagefraction{.5}

\setlength\floatsep    {8\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\textfloatsep{8\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\intextsep   {8\p@ \@plus 2\p@ \@minus 2\p@}
%==================================================================

%===== MISCELLANEOUS ==============================================
\newcommand\internet[1]{\texttt{#1}}
\newcommand\email[1]{\internet{#1}}
%==================================================================

%===== CAPTIONS ===================================================
\renewcommand\figurename{\textsc{Figure}}
\renewcommand\tablename{\textsc{Table}}

\long\def\@caption#1[#2]#3{%
  \par
  \addcontentsline{\csname ext@#1\endcsname}{#1}%
    {\protect\numberline{\csname the#1\endcsname}{\ignorespaces #2}}%
  \begingroup
    \@parboxrestore
    \footnotesize
    \centering
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
  \endgroup}
  
\newlength\captionWidth
\setlength\captionWidth{0.9\textwidth}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \begin{minipage}{\captionWidth}
  \sbox\@tempboxa{#1. \ #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1. \ #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \end{minipage}
  \vskip\belowcaptionskip}
  
\setlength\belowcaptionskip{10\p@ \@plus 1\p@ \@minus 1\p@}
%==================================================================

%===== TABLE OF CONTENTS ==========================================
\renewcommand\contentsname{Contents}
\setcounter{tocdepth}{0}

\renewcommand\tableofcontents{%
  \newoddpage%
  \thispagestyle{Empty}%
  \markboth{\contentsname}{\contentsname}%
  \vspace*{12mm}%
  \begin{center}
    \Large\bfseries
    \contentsname
  \vspace{6mm}%
  \end{center}
  {\parskip 10\p@ \@plus4\p@ \@minus4\p@
   %\small
   \@starttoc{toc}}%
  \newpage%
}

\renewcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{-\@highpenalty}%
    \addvspace{1.5ex \@plus\p@}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      {\leavevmode
       \normalsize \bfseries #1\hfil \hb@xt@\@pnumwidth{\hss #2}}\par
       \nobreak
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
    \endgroup
  \fi}
  
\newcommand*\l@paper{\@dottedtocline{0}{0ex}{3ex}}
%==================================================================

\endinput
